@@ -18,6 +18,13 @@ from .types import (
 )
 from .decorators import tool, prompt
 from .adapter import TransportAdapter
+from .exceptions import (
+    TransportError,
+    InvalidRequestError,
+    UnsupportedMediaTypeError,
+    NotAcceptableError,
+    AuthenticationError,
+)
 
 __version__ = "0.1.0"
 __all__ = [
@@ -32,4 +39,9 @@ __all__ = [
     "PromptArgument",
     "tool",
     "prompt",
+    "TransportError",
+    "InvalidRequestError",
+    "UnsupportedMediaTypeError",
+    "NotAcceptableError",
+    "AuthenticationError",
 ]
